import { useSpring, animated } from "@react-spring/web";
import React, { useEffect, useRef, useState } from "react";
import { VscDebugBreakpointLog } from "react-icons/vsc";
import { useTranslation } from "react-i18next";
import "../css/Roadmap.css";
import backgroundRoadMap from "../../../assets/images/home-roadmap-road.png";
import boderItem from "../../../assets/images/bt-bg.png";
import dotOrange from "../../../assets/images/dot-orange.svg";

type Props = {};

const RoadMap = (props: Props) => {
  const [isVisible, setIsVisible] = useState(false);
  const { t } = useTranslation("roadmapHome");
  const [roadMapData, setRoadmapData] = useState([]);

  useEffect(() => {
    setRoadmapData(t("array", { returnObjects: true }));
    const section = document.getElementById("roadmap");
    const observer = new IntersectionObserver(
      ([entry]) => {
        setIsVisible(entry.isIntersecting);
      },
      { threshold: 0.1 }
    );

    if (!section) {
      return;
    }
    observer.observe(section);

    return () => {
      observer.unobserve(section);
    };
  }, [t]);

  useEffect(() => {
    console.log("isVisible", isVisible);
  }, [isVisible]);

  const styles = useSpring({
    opacity: isVisible ? 1 : 0,
    transform: isVisible ? "scaleX(1)" : "scaleX(0)",
    config: {
      duration: 500,
    },
  });
  const styles1 = useSpring({
    opacity: isVisible ? 1 : 0,
    transform: isVisible ? "scaleY(1)" : "scaleY(0)",
    config: {
      duration: 500,
    },
  });

  return (
    <div
      className="container mx-auto text-white md:min-h-[60vh] animate-on-scroll my-20 w-[94%] "
      id="roadmap"
    >
      <h1 className="text-4xl font-bold text-center hover:text-orange-400 pb-20 relative">
        Road Map
      </h1>
      <div className="max-tablet:flex max-tablet:flex-wrap max-tablet:justify-between max-tablet:pl-4 gap-5  max-tablet:h-full relative tablet:h-[716px] desktop:h-[895px]">
        <div
          className="hidden tablet:block absolute top-[50%] left-[50%] translate-x-[-50%] translate-y-[-50%]  tablet:w-[880px] tablet:h-[280px] bg-cover bg-no-repeat bg-center desktop:w-[1020px] desktop:h-[325px]"
          style={{ backgroundImage: `url(${backgroundRoadMap})` }}
        ></div>
        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[360px] tablet:left-[0px] desktop:top-[460px] desktop:left-[40px]">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Q2 2023
            </span>
          </div>
          <div className="flex flex-col gap-3">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Form teams
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Ideas & concept
              </span>
            </div>
          </div>
        </div>
        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[40px] tablet:left-[60px] desktop:top-[120px] desktop:left-[100px]">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              July 2023
            </span>
          </div>
          <div className="flex flex-col gap-3 max-w-[280px]">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Complete POC{" "}
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Launch Hospital Contract Testnet V1
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Publish Blue Paper in International Conference
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Pitch Deck Release
              </span>
            </div>
          </div>
        </div>
        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[530px] tablet:left-[140px] desktop:top-[620px] desktop:left-[240px] ">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Aug 2023
            </span>
          </div>
          <div className="flex flex-col gap-3">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Participate world finalist of WSEEC
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Publish White Paper
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Alpha Launching
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Design Marketplace
              </span>
            </div>
          </div>
        </div>
        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[340px] tablet:left-[340px] tablet1:left-[400px] desktop:top-[424px] desktop:left-[444px] ">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Sep & Oct 2023
            </span>
          </div>
          <div className="flex flex-col gap-3">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Launch Marketplace Testnet
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Partnership expansion with clinics
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Fund raising (Angel)
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Community growth
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                ERC-20 Token Airdrop Campaign
              </span>
            </div>
          </div>
        </div>

        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[20px] tablet:left-[362px] desktop:top-[90px] desktop:left-[500px] ">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Nov 2023
            </span>
          </div>
          <div className="flex flex-col gap-3 max-w-[280px] desktop:max-w-[350px]">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Launch Marketplace V2 Testnet
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                IDO and Token Listing
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Staking
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Customize products for hospitals and clinics
              </span>
            </div>
          </div>
        </div>

        <div className=" max-tablet:w-[40%] tablet:absolute tablet:bottom-[130px] tablet:right-[20px] desktop:right-[80px] desktop:bottom-[160px]  ">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Dec 2023
            </span>
          </div>
          <div className="flex flex-col gap-3 max-w-[280px]">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Beta Launching
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Partnership expansion with hospitals
              </span>
            </div>
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Co-branding Partnerships
              </span>
            </div>
          </div>
        </div>

        <div className=" max-tablet:w-[40%] tablet:absolute tablet:top-[80px] tablet:right-[0px] desktop:right-[20px] desktop:top-[140px]">
          <div
            className="w-max bg-no-repeat px-8 py-[16px] bg-center bg-contain"
            style={{ backgroundImage: `url(${boderItem})` }}
          >
            <span className="m-1 max-tablet:text-2xl  tablet:text-[18px] desktop:text-[20px] font-bold">
              Jan 2024
            </span>
          </div>
          <div className="flex flex-col gap-3 max-w-[280px]">
            <div className="flex items-center gap-2">
              <img className="w-[14px] h-[12px]" src={dotOrange} alt="" />
              <span className="text-[18px] tablet:text-[14px] desktop:text-[18px]">
                Launch Mainnet V1
              </span>
            </div>
          </div>
        </div>
      </div>
      {/* <animated.div
        id="timeline"
        style={{ ...styles }}
        className="w-full flex flex-col gap-y-4 lg:flex-row"
      >
        {roadMapData.map((item: any, index: any) => {
          return (
            <div
              key={index}
              className="tl-item w-[80%]mx-auto lg:hover:w-[150%!important] "
            >
              <div
                className="tl-bg"
                style={{
                  backgroundImage: `url("https://picsum.photos/200/300")`,
                }}
              ></div>
              <h4 className="tl-title">{item.phase}</h4>
              <ol className="tl-content w-[90%] md:w-[60%] lg:w-[90%] mx-auto flex flex-col gap-y-[12px]">
                {item.listTitle.map((listItem: any, index: any) => {
                  return (
                    <li key={index} className="flex items-center gap-x-[20px]">
                      <VscDebugBreakpointLog
                        style={{
                          color: "#B051F2",
                        }}
                      />
                      <p>{listItem}</p>
                    </li>
                  );
                })}
              </ol>
            </div>
          );
        })}
      </animated.div> */}
    </div>
  );
};

export default RoadMap;
